@@ -6,6 +6,8 @@
 #' @param file Name of file with full path relative to Dropbox root
 #' @param  dest A temporary directory where a csv file is downloaded before being read into memory
 #' @param  ... Additional arguments into \code{read.csv}
+#' @template token
+#' @importFrom utils read.csv
 #' @export
 #' @examples \dontrun{
 #' write.csv(iris, file = "iris.csv")
@@ -13,8 +15,8 @@
 #' # Now let's read this back into an R session
 #' new_iris <- drop_read_csv("iris.csv")
 #'}
-drop_read_csv <- function(file, dest = tempdir(), ...) {
+drop_read_csv <- function(file, dest = tempdir(), dtoken = get_dropbox_token(), ...) {
     localfile = paste0(dest, "/", basename(file))
-    drop_get(file, local_file = localfile, overwrite = TRUE)
+    drop_get(file, local_file = localfile, overwrite = TRUE, dtoken = dtoken)
     read.csv(localfile, ...)
 }
